"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.withoutAllContextHeaders = exports.extractFunctionsExtendedContextFromHeader = void 0;
const zlib_1 = require("zlib");
const FunctionsExtendedContextHeaderKey = 'X-Functions-Extended-Context';
/**
 * extractContextFromHTTPHeader 从 HTTP 请求头中提取上下文
 * @param headers
 * @param headerKey
 * @returns
 */
function extractContextFromHTTPHeader(headers, headerKey) {
    const empty = {};
    if (!headerKey) {
        return empty;
    }
    const headerValue = headers[headerKey.toLowerCase()];
    if (!headerValue) {
        return empty;
    }
    // Encode Base64 first, then gunzip
    try {
        const unzipped = (0, zlib_1.gunzipSync)(Buffer.from(headerValue, 'base64')).toString('utf-8');
        return JSON.parse(unzipped);
    }
    catch (e) {
        return empty;
    }
}
/**
 * extractFunctionsExtendedContextFromHeader 从 HTTP 请求头中提取 扩展的调用上下文
 * @param headers  HTTP 请求头
 * @returns 扩展的调用上下文
 */
const extractFunctionsExtendedContextFromHeader = (headers) => {
    return extractContextFromHTTPHeader(headers, FunctionsExtendedContextHeaderKey);
};
exports.extractFunctionsExtendedContextFromHeader = extractFunctionsExtendedContextFromHeader;
const withContextHeaders = (headers, targetKeys) => {
    const newHeaders = { ...headers };
    for (const target of targetKeys) {
        const th = target.toLowerCase();
        if (newHeaders[th]) {
            delete newHeaders[th];
        }
    }
    return newHeaders;
};
const withoutAllContextHeaders = (headers) => {
    return withContextHeaders(headers, [FunctionsExtendedContextHeaderKey]);
};
exports.withoutAllContextHeaders = withoutAllContextHeaders;
//# sourceMappingURL=invoker.js.map